Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

Action Space Catalog

Each robot exposes one or more action modes, selected at launch via env.robot.action_mode=<mode> (the default mode is marked *). Dims is the action-vector length and Scale is the multiplier applied to the policy output before it reaches the controller; ? means the value is resolved from the loaded asset at runtime.

RobotModeControllerDimsScale
Canadarm3diff_ik *Differential Inverse Kinematics60.1
Canadarm3joint_pos_relRelative Joint Position71.0
Frankadiff_ik *Differential Inverse Kinematics60.1
Frankaosc_fixedOperational Space Controller6pos=0.1, ori=0.1
Frankaosc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Frankaosc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Frankajoint_pos_relRelative Joint Position71.0
Kinova J2N6Sdiff_ik *Differential Inverse Kinematics60.1
Kinova J2N6Sjoint_pos_relRelative Joint Position61.0
Kinova J2N7Sdiff_ik *Differential Inverse Kinematics60.1
Kinova J2N7Sjoint_pos_relRelative Joint Position71.0
Kinova Gen3N7diff_ik *Differential Inverse Kinematics60.1
Kinova Gen3N7osc_fixedOperational Space Controller6pos=0.1, ori=0.1
Kinova Gen3N7osc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Kinova Gen3N7osc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Kinova Gen3N7smooth_oscSmooth Operational Space Controller6pos=0.1, ori=0.1
Kinova Gen3N7joint_pos_relRelative Joint Position71.0
Levion Armsdual_arm_joint_pos_abs *Joint Position To Limits41.0
So Arm100 D5diff_ik *Differential Inverse Kinematics60.05
So Arm100 D5osc_var_stiffnessOperational Space Controller12pos=0.05, ori=0.05, stiffness=120.0
So Arm100 D5joint_pos_relRelative Joint Position51.0
So Arm100 D7diff_ik *Differential Inverse Kinematics60.05
So Arm100 D7joint_pos_relRelative Joint Position71.0
Unitree Z1diff_ik *Differential Inverse Kinematics60.05
Unitree Z1joint_pos_relRelative Joint Position61.0
Ur3diff_ik *Differential Inverse Kinematics60.1
Ur3osc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur3osc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur3osc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur3joint_pos_relRelative Joint Position61.0
Ur3Ediff_ik *Differential Inverse Kinematics60.1
Ur3Eosc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur3Eosc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur3Eosc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur3Ejoint_pos_relRelative Joint Position61.0
Ur5diff_ik *Differential Inverse Kinematics60.1
Ur5osc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur5osc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur5osc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur5joint_pos_relRelative Joint Position61.0
Ur5Ediff_ik *Differential Inverse Kinematics60.1
Ur5Eosc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur5Eosc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur5Eosc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur5Ejoint_pos_relRelative Joint Position61.0
Ur10diff_ik *Differential Inverse Kinematics60.1
Ur10osc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur10osc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur10osc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur10joint_pos_relRelative Joint Position61.0
Ur10Ediff_ik *Differential Inverse Kinematics60.1
Ur10Eosc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur10Eosc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur10Eosc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur10Ejoint_pos_relRelative Joint Position61.0
Ur16Ediff_ik *Differential Inverse Kinematics60.1
Ur16Eosc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur16Eosc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur16Eosc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur16Ejoint_pos_relRelative Joint Position61.0
Ur20diff_ik *Differential Inverse Kinematics60.1
Ur20osc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur20osc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur20osc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur20joint_pos_relRelative Joint Position61.0
Ur30diff_ik *Differential Inverse Kinematics60.1
Ur30osc_fixedOperational Space Controller6pos=0.1, ori=0.1
Ur30osc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Ur30osc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Ur30joint_pos_relRelative Joint Position61.0
Random Ur Manipulatordiff_ik *Differential Inverse Kinematics60.1
Random Ur Manipulatorosc_fixedOperational Space Controller6pos=0.1, ori=0.1
Random Ur Manipulatorosc_var_stiffnessOperational Space Controller12pos=0.1, ori=0.1, stiffness=120.0
Random Ur Manipulatorosc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Random Ur Manipulatorjoint_pos_relRelative Joint Position61.0
Vispadiff_ik *Differential Inverse Kinematics60.05
Vispaosc_var_fullOperational Space Controller18pos=0.1, ori=0.1, stiffness=120.0, damping=1.0
Vispajoint_pos_relRelative Joint Position61.0
Zeroglab Armsdual_arm_osc *Operational Space Controller24arm_ceiling: pos=0.1, ori=0.1, stiffness=120.0, arm_wall: pos=0.1, ori=0.1, stiffness=120.0
Humanoid21joint_pos *Joint Position To Limitsruntime-resolved1.0
Humanoid28joint_pos *Joint Position To Limitsruntime-resolved1.0
Unitree H1joint_pos *Joint Position To Limitsruntime-resolved1.0
Unitree G1joint_pos *Joint Position To Limitsruntime-resolved1.0
Crazyfliebody_acc *Multicopter Body Accelerationruntime-resolved0.5
Ingenuitybody_acc *Multicopter Body Acceleration20.5
Heronthrust *Thrust21.0
Anymal Cjoint_pos *Joint Position To Limitsruntime-resolved1.0
Anymal Djoint_pos *Joint Position To Limitsruntime-resolved1.0
Random Anymal Quadrupedjoint_pos *Joint Position To Limitsruntime-resolved1.0
Cadredrive *Wheeled Driveruntime-resolvedlin=0.4, ang=0.7853981633974483
Cassiejoint_pos *Joint Position To Limits121.0
Huskydrive *Wheeled Driveruntime-resolvedlin=0.1, ang=0.7853981633974483
Leo Roverdrive *Wheeled Driveruntime-resolvedlin=0.4, ang=1.0471975511965976
Mars Roverdrive *Wheeled Driveruntime-resolvedlin=0.5, ang=0.7853981633974483
Niftynifty *Joint Velocity12joint_vel_wheel_drive=1.5707963267948966, joint_pos_steer=0.7853981633974483, joint_pos_suspension_yaw=0.5235987755982988, joint_pos_suspension_roll=0.2617993877991494
Open Source Roverdrive *Wheeled Driveruntime-resolvedlin=0.2, ang=0.3490658503988659
Perseverancedrive *Wheeled Driveruntime-resolvedlin=0.7, ang=1.3089969389957472
Pragyandrive *Wheeled Driveruntime-resolvedlin=0.35, ang=1.3962634015954636
Raph Roverdrive *Wheeled Driveruntime-resolvedlin=0.4, ang=1.0471975511965976
Raph Roverdrive_filteredFiltered Wheeled Driveruntime-resolvedlin=0.4, ang=1.0471975511965976
Spotjoint_pos *Joint Positionruntime-resolved0.2
Unitree A1joint_pos *Joint Position To Limitsruntime-resolved1.0
Unitree Go1joint_pos *Joint Position To Limitsruntime-resolved1.0
Unitree Go2joint_pos *Joint Position To Limitsruntime-resolved1.0
Random Unitree Quadrupedjoint_pos *Joint Position To Limitsruntime-resolved1.0
Floating Platformthrust_only *Thrust81.0
Floating Platformthrust_and_reactionThrust9thrust=1.0, reaction_wheel_torque=0.05
Int Ball1thrust *Thrust61.0
Int Ball2thrust *Thrust61.0
Apollo Landerthrust *Thrust171.0
Peregrine Landerthrust *Thrust171.0
Vikram Landerthrust *Thrust131.0
Resilience Landerthrust *Thrust91.0
Random Landerthrust *Thrust31.0
Issbody_acc *Body Accelerationruntime-resolved0.05
Gatewaybody_acc *Body Accelerationruntime-resolved0.05
Cubesatthrust *Thrust61.0
Satellite Mockupthrust *Thrust121.0
Venus Expressthrust *Thrust191.0
Starshipthrust *Thrust181.0
Super Heavythrust *Thrust591.0